@@ -194,8 +194,11 @@ class BotMaestroSDK:
         """
         url = f'{self._server}/app/api/task/create'
 
-        data = {"activityLabel": activity_label, "jsonParams": json.dumps(parameters),
-                "taskForTest": str(test).lower(), "access_token": self.access_token}
+        data = {
+            "activityLabel": activity_label, "taskForTest": str(test).lower(), "access_token": self.access_token
+        }
+        data.update(parameters)
+
         with requests.post(url, data=data) as req:
             if req.status_code == 200:
                 payload = req.json().get('payload')
@@ -384,7 +387,6 @@ class BotMaestroSDK:
 
         Args:
             activity_label: The activity unique identifier.
-            date: Initial date for log information in the format DD/MM/YYYY. If empty all information is retrieved.
 
         Returns:
             Log entry list. Each element in the list is a dictionary in which keys are Column names and values are
